pub struct Spi { /* private fields */ }Expand description
Serial Peripheral Interfaces (SPI)
Implementations
Sourceimpl Spi
impl Spi
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn stat(self) -> Reg<Stat, RW>
pub const fn stat(self) -> Reg<Stat, RW>
SPI Status. Some status flags can be cleared by writing a 1 to that bit position.
Sourcepub const fn intenset(self) -> Reg<Intenset, RW>
pub const fn intenset(self) -> Reg<Intenset, RW>
SPI Interrupt Enable read and Set. A complete value may be read from this register. Writing a 1 to any implemented bit position causes that bit to be set.
Sourcepub const fn intenclr(self) -> Reg<Intenclr, W>
pub const fn intenclr(self) -> Reg<Intenclr, W>
SPI Interrupt Enable Clear. Writing a 1 to any implemented bit position causes the corresponding bit in INTENSET to be cleared.
Sourcepub const fn fifotrig(self) -> Reg<Fifotrig, RW>
pub const fn fifotrig(self) -> Reg<Fifotrig, RW>
FIFO trigger settings for interrupt and DMA request.
Sourcepub const fn fifointenset(self) -> Reg<Fifointenset, RW>
pub const fn fifointenset(self) -> Reg<Fifointenset, RW>
FIFO interrupt enable set (enable) and read register.
Sourcepub const fn fifointenclr(self) -> Reg<Fifointenclr, RW>
pub const fn fifointenclr(self) -> Reg<Fifointenclr, RW>
FIFO interrupt enable clear (disable) and read register.
Sourcepub const fn fifointstat(self) -> Reg<Fifointstat, R>
pub const fn fifointstat(self) -> Reg<Fifointstat, R>
FIFO interrupt status register.
Sourcepub const fn fifordnopop(self) -> Reg<Fifordnopop, R>
pub const fn fifordnopop(self) -> Reg<Fifordnopop, R>
FIFO data read with no FIFO pop.